@@ -19,15 +19,25 @@ type UI struct {
 	ConstGC               bool
 }
 
+// SetAnalyzer sets analyzer instance
+func (ui *UI) SetAnalyzer(a Analyzer) {
+	ui.Analyzer = a
+}
+
 // SetFollowSymlinks sets whether symlinks to files should be followed
 func (ui *UI) SetFollowSymlinks(v bool) {
 	ui.Analyzer.SetFollowSymlinks(v)
 }
 
+// SetShowAnnexedSize sets whether to use annexed size of git-annex files
+func (ui *UI) SetShowAnnexedSize(v bool) {
+	ui.Analyzer.SetShowAnnexedSize(v)
+}
+
 // binary multiplies prefixes (IEC)
 const (
-	_          = iota
-	Ki float64 = 1 << (10 * iota)
+	_ float64 = 1 << (10 * iota)
+	Ki
 	Mi
 	Gi
 	Ti
