@@ -217,7 +217,7 @@ func TestSpawnShell(t *testing.T) {
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
 	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
-	var called = false
+	called := false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
 		return nil
@@ -247,7 +247,7 @@ func TestSpawnShellWithoutDir(t *testing.T) {
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
 	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
-	var called = false
+	called := false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
 		return nil
@@ -269,7 +269,7 @@ func TestSpawnShellWithWrongDir(t *testing.T) {
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
 	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
-	var called = false
+	called := false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
 		return nil
@@ -294,7 +294,7 @@ func TestSpawnShellWithError(t *testing.T) {
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
 	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
-	var called = false
+	called := false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
 		return errors.New("wrong shell")
@@ -310,6 +310,62 @@ func TestSpawnShellWithError(t *testing.T) {
 	assert.True(t, ui.pages.HasPage("error"))
 }
 
+func TestSpawnShellWithNoSpawnShell(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(false)
+	buff := &bytes.Buffer{}
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
+	called := false
+	ui.exec = func(argv0 string, argv, envv []string) error {
+		called = true
+		return nil
+	}
+
+	ui.done = make(chan struct{})
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	ui.SetNoSpawnShell()
+	key := ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'b', 0))
+	assert.Nil(t, key)
+	assert.False(t, called)
+}
+
+func TestOpenItemWithNoSpawnShell(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(false)
+	buff := &bytes.Buffer{}
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
+
+	ui.done = make(chan struct{})
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	ui.SetNoSpawnShell()
+	key := ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'o', 0))
+	assert.Nil(t, key)
+}
+
 func TestShowConfirm(t *testing.T) {
 	simScreen := testapp.CreateSimScreen()
 	defer simScreen.Fini()
@@ -364,6 +420,18 @@ func TestMarkEmpty(t *testing.T) {
 	assert.NotNil(t, key)
 }
 
+func TestIgnoreEmpty(t *testing.T) {
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui.done = make(chan struct{})
+
+	key := ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'I', 0))
+	assert.NotNil(t, key)
+}
+
 func TestDelete(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -400,6 +468,36 @@ func TestDelete(t *testing.T) {
 	assert.NoDirExists(t, "test_dir/nested")
 }
 
+func TestDeleteWithNoDelete(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui.done = make(chan struct{})
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+
+	ui.table.Select(0, 0)
+
+	ui.SetNoDelete()
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'd', 0))
+
+	assert.DirExists(t, "test_dir/nested")
+}
+
 func TestDeleteMarked(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -498,6 +596,36 @@ func TestMarkParent(t *testing.T) {
 	assert.Equal(t, len(ui.markedRows), 0)
 }
 
+func TestIgnoreParent(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui.done = make(chan struct{})
+	ui.askBeforeDelete = false
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
+	assert.Equal(t, 1, ui.table.GetRowCount())
+
+	ui.table.Select(0, 0)
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'I', 0))
+
+	assert.Equal(t, len(ui.ignoredRows), 0)
+}
+
 func TestEmptyDir(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -574,6 +702,45 @@ func TestMarkedEmptyDir(t *testing.T) {
 	assert.NoDirExists(t, "test_dir/nested/subnested")
 }
 
+func TestIgnoreDir(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui.done = make(chan struct{})
+	ui.askBeforeDelete = false
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+
+	ui.table.Select(0, 0)
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0)) // into nested
+	assert.Equal(t, 3, ui.table.GetRowCount())
+
+	ui.table.Select(1, 0) // subnested
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'I', 0)) // ignore subnested
+
+	row, _ := ui.table.GetSelection()
+	assert.Equal(t, 2, row) // selection moves to next row
+
+	ui.table.Select(1, 0)
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'I', 0)) // unignore subnested
+}
+
 func TestEmptyFile(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -862,6 +1029,11 @@ func TestSorting(t *testing.T) {
 
 	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
+	ui.table.Select(1, 0)
+	// mark the item for deletion
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, ' ', 0))
+	assert.Equal(t, 1, len(ui.markedRows))
+
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 's', 0))
 	assert.Equal(t, "size", ui.sortBy)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'C', 0))
@@ -870,6 +1042,9 @@ func TestSorting(t *testing.T) {
 	assert.Equal(t, "name", ui.sortBy)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'M', 0))
 	assert.Equal(t, "mtime", ui.sortBy)
+
+	// marking should be dropped after sorting
+	assert.Equal(t, 0, len(ui.markedRows))
 }
 
 func TestShowFile(t *testing.T) {
