@@ -1,6 +1,7 @@
 package tui
 
 import (
+	"fmt"
 	"strconv"
 	"strings"
 
@@ -31,6 +32,7 @@ Item under cursor:
                [::b]d     [white:black:-]Delete file or directory
                [::b]e     [white:black:-]Empty file or directory
 			   [::b]space [white:black:-]Mark file or directory for deletion
+			   [::b]I     [white:black:-]Ignore file or directory
                [::b]v     [white:black:-]Show content of file
                [::b]o     [white:black:-]Open file or directory in external program
                [::b]i     [white:black:-]Show info about item
@@ -41,6 +43,7 @@ Sort by (twice toggles asc/desc):
                [::b]C     [white:black:-]Sort by file count (asc/desc)
                [::b]M     [white:black:-]Sort by mtime (asc/desc)`
 
+// nolint: funlen // Why: complex function
 func (ui *UI) showDir() {
 	var (
 		totalUsage int64
@@ -84,18 +87,30 @@ func (ui *UI) showDir() {
 
 	ui.sortItems()
 
-	if ui.ShowRelativeSize {
-		for _, item := range ui.currentDir.GetFiles() {
+	unlock := ui.currentDir.RLock()
+	defer unlock()
+
+	i := rowIndex
+	maxUsage = 0
+	maxSize = 0
+	for _, item := range ui.currentDir.GetFiles() {
+		if _, ignored := ui.ignoredRows[i]; ignored {
+			i++
+			continue
+		}
+
+		if ui.ShowRelativeSize {
 			if item.GetUsage() > maxUsage {
 				maxUsage = item.GetUsage()
 			}
 			if item.GetSize() > maxSize {
 				maxSize = item.GetSize()
 			}
+		} else {
+			maxSize += item.GetSize()
+			maxUsage += item.GetUsage()
 		}
-	} else {
-		maxUsage = ui.currentDir.GetUsage()
-		maxSize = ui.currentDir.GetSize()
+		i++
 	}
 
 	for i, item := range ui.currentDir.GetFiles() {
@@ -106,18 +121,25 @@ func (ui *UI) showDir() {
 			continue
 		}
 
-		totalUsage += item.GetUsage()
-		totalSize += item.GetSize()
-		itemCount += item.GetItemCount()
+		_, ignored := ui.ignoredRows[rowIndex]
+
+		if !ignored {
+			totalUsage += item.GetUsage()
+			totalSize += item.GetSize()
+			itemCount += item.GetItemCount()
+		}
 
 		_, marked := ui.markedRows[rowIndex]
-		cell := tview.NewTableCell(ui.formatFileRow(item, maxUsage, maxSize, marked))
+		cell := tview.NewTableCell(ui.formatFileRow(item, maxUsage, maxSize, marked, ignored))
 		cell.SetReference(ui.currentDir.GetFiles()[i])
 
-		if marked {
+		switch {
+		case ignored:
+			cell.SetStyle(tcell.Style{}.Foreground(tview.Styles.SecondaryTextColor))
+		case marked:
 			cell.SetStyle(tcell.Style{}.Foreground(tview.Styles.PrimaryTextColor))
 			cell.SetBackgroundColor(tview.Styles.ContrastBackgroundColor)
-		} else {
+		default:
 			cell.SetStyle(tcell.Style{}.Foreground(tcell.ColorDefault))
 		}
 
@@ -127,11 +149,19 @@ func (ui *UI) showDir() {
 
 	var footerNumberColor, footerTextColor string
 	if ui.UseColors {
-		footerNumberColor = "[#ffffff:#2479d0:b]"
-		footerTextColor = "[black:#2479d0:-]"
+		footerNumberColor = fmt.Sprintf(
+			"[%s:%s:b]",
+			ui.footerNumberColor,
+			ui.footerBackgroundColor,
+		)
+		footerTextColor = fmt.Sprintf(
+			"[%s:%s:-]",
+			ui.footerTextColor,
+			ui.footerBackgroundColor,
+		)
 	} else {
 		footerNumberColor = "[black:white:b]"
-		footerTextColor = "[black:white:-]"
+		footerTextColor = blackOnWhite
 	}
 
 	selected := ""
@@ -141,7 +171,7 @@ func (ui *UI) showDir() {
 	}
 
 	ui.footerLabel.SetText(
-		selected +
+		selected + footerTextColor +
 			" Total disk usage: " +
 			footerNumberColor +
 			ui.formatSize(totalUsage, true, false) +
@@ -194,11 +224,19 @@ func (ui *UI) showDevices() {
 
 	var footerNumberColor, footerTextColor string
 	if ui.UseColors {
-		footerNumberColor = "[#ffffff:#2479d0:b]"
-		footerTextColor = "[black:#2479d0:-]"
+		footerNumberColor = fmt.Sprintf(
+			"[%s:%s:b]",
+			ui.footerNumberColor,
+			ui.footerBackgroundColor,
+		)
+		footerTextColor = fmt.Sprintf(
+			"[%s:%s:-]",
+			ui.footerTextColor,
+			ui.footerBackgroundColor,
+		)
 	} else {
 		footerNumberColor = "[black:white:b]"
-		footerTextColor = "[black:white:-]"
+		footerTextColor = blackOnWhite
 	}
 
 	ui.footerLabel.SetText(
@@ -250,19 +288,10 @@ func (ui *UI) showHelp() {
 	text.SetTitle(" gdu help ")
 	text.SetScrollable(true)
 
-	if ui.UseColors {
-		text.SetText(
-			strings.ReplaceAll(
-				strings.ReplaceAll(helpText, "[::b]", "[red]"),
-				"[white:black:-]",
-				"[white]",
-			),
-		)
-	} else {
-		text.SetText(helpText)
-	}
+	formattedHelpText := ui.formatHelpTextFor()
+	text.SetText(formattedHelpText)
 
-	maxHeight := strings.Count(helpText, "\n") + 7
+	maxHeight := strings.Count(formattedHelpText, "\n") + 7
 	_, height := ui.screen.Size()
 	if height > maxHeight {
 		height = maxHeight
@@ -280,3 +309,29 @@ func (ui *UI) showHelp() {
 	ui.pages.AddPage("help", flex, true, true)
 	ui.app.SetFocus(text)
 }
+
+func (ui *UI) formatHelpTextFor() string {
+	lines := strings.Split(helpText, "\n")
+
+	for i, line := range lines {
+		if ui.UseColors {
+			lines[i] = strings.ReplaceAll(
+				strings.ReplaceAll(line, defaultColorBold, "[red]"),
+				whiteOnBlack,
+				"[white]",
+			)
+		}
+
+		if ui.noDelete && (strings.Contains(line, "Empty file or directory") ||
+			strings.Contains(line, "Delete file or directory")) {
+			lines[i] += " (disabled)"
+		}
+
+		if ui.noSpawnShell && (strings.Contains(line, "Spawn shell in current directory") ||
+			strings.Contains(line, "Open file or directory in external program")) {
+			lines[i] += " (disabled)"
+		}
+	}
+
+	return strings.Join(lines, "\n")
+}
